@@ -2,7 +2,7 @@
 package Perl::Structure::CodeReference;
 use strict;
 use warnings;
-use Perl::Types;
+use Perl::Config;  # don't use Perl::Types inside itself, in order to avoid circular includes
 our $VERSION = 0.001_000;
 
 # [[[ OO INHERITANCE ]]]
@@ -14,8 +14,7 @@ our hashref $properties = {};
 
 # [[[ SUB-TYPES ]]]
 
-package  # hide from PAUSE indexing
-    coderef;
+package coderef;
 use strict;
 use warnings;
 use parent -norequire, qw(Perl::Structure::CodeReference);
