@@ -6,8 +6,8 @@ use types;
 our $VERSION = 0.004_000;
 
 # [[[ OO INHERITANCE ]]]
-use parent qw(Perl::Class);
-use Perl::Class;
+use parent qw(class);
+use class;
 
 # [[[ CRITICS ]]]
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
