@@ -5,9 +5,9 @@
 # <<< PARSE_ERROR: 'Unexpected Token:  ]' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ CRITICS ]]]
@@ -16,7 +16,7 @@ our $VERSION = 0.001_000;
 
 # [[[ OPERATIONS ]]]
 
-my arrayref_arrayref $array_array = [
+my arrayref::arrayref $array_array = [
     my arrayref::integer $TYPED_array_array_0 = [ 17, -23, 1_701 ],
     my arrayref::number $TYPED_array_array_1 = [ 42 / 1_701, 21.12, 2_112.23 ],
     my arrayref::string $TYPED_array_array_2 = [ 'strings are scalars, too', 'hello world', 'last one' ],
