@@ -7,9 +7,9 @@
 # <<< PARSE_ERROR: 'Unexpected Token:  @foo' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ CRITICS ]]]
