@@ -7,9 +7,9 @@
 # <<< EXECUTE_SUCCESS: 'The middle child is Groucho' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ CRITICS ]]]
