@@ -2,10 +2,10 @@
 # <<< PARSE_ERROR: 'ERROR ECOPAPL02' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 package Perl::Types::Test::Properties::Class_00_Bad_09;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ OO INHERITANCE ]]]
@@ -17,6 +17,6 @@ our hashref $properties
     = { empty_property => y integer $TYPED_empty_property = 2 };
 
 # [[[ SUBROUTINES & OO METHODS ]]]
-sub empty_method { { my integer::method $RETURN_TYPE }; return 2; }
+sub empty_method { { my integer $RETURN_TYPE }; return 2; }
 
 1;                  # end of class
