@@ -5,9 +5,9 @@
 # <<< EXECUTE_SUCCESS: '2208' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.000_010;
 
 # [[[ CRITICS ]]]
