@@ -4,9 +4,9 @@
 # <<< EXECUTE_SUCCESS: 'size of $foo is 10' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ CRITICS ]]]
